@@ -21,13 +21,15 @@ mod noise_elimination_technology;
 mod polarized_fractal_efficiency;
 mod re_flex;
 mod roc;
+mod roofing_filter;
 mod rsi;
 mod sma;
+mod super_smoother;
+mod tanh;
 mod trend_flex;
 mod variance_stabilizing_transformation;
 mod vsct;
 mod welford_online;
-//pub mod roofing_filter;  // temporarily disabled roofing_filter until it is working properly
 
 mod add;
 mod constant;
@@ -57,13 +59,15 @@ pub use noise_elimination_technology::NET;
 pub use polarized_fractal_efficiency::PolarizedFractalEfficiency;
 pub use re_flex::ReFlex;
 pub use roc::ROC;
+pub use roofing_filter::RoofingFilter;
 pub use rsi::RSI;
 pub use sma::SMA;
+pub use super_smoother::SuperSmoother;
+pub use tanh::Tanh;
 pub use trend_flex::TrendFlex;
 pub use variance_stabilizing_transformation::VST;
 pub use vsct::VSCT;
 pub use welford_online::WelfordOnline;
-// Pub use roofing_filter::RoofingFilter
 
 pub use add::Add;
 pub use constant::Constant;
